#+ setup, include=FALSE
library(lme4)

setwd("~/")

#+ include=FALSE
data1 <- read.csv("Finnish_dataset-final.csv",header=T)

####analysis####

data3=subset(data1, !is.na(normalNAd))
data3$normalNAd

#centering the PND and tokenfreq data to the mean (trying to prevent convergence failures)
data3$subclass.PND=log(data3$subclass.PND)
data3$token.freq=log(data3$token.freq+1)

mean.subclass.PND=mean(data3$subclass.PND)
mean.tokenfreq=mean(data3$token.freq)

#for token.freq
# mean subtraction
center_mean <- function(x) {
    x_mean=mean.tokenfreq
    x - x_mean
}

# apply it
data3$token.freq=center_mean(data3$token.freq)
head(data1)

#for PND
# mean subtraction
center_mean <- function(x) {
    x_mean=mean.subclass.PND
    x - x_mean
}

# apply it
data3$subclass.PND=center_mean(data3$subclass.PND)

#centering age to 48 months
center_mean <- function(x) {
    x_mean=48
    x - x_mean
}

# apply it
data3$ageM=center_mean(data3$ageM)
head(data3)


full=glmer(normalNAd ~ (1|participant)+ (1|verb) + ageM + token.freq + subclass.PND  + subclass.PND:token.freq + ageM:token.freq + subclass.PND:ageM, data=data3, family=binomial)
#does not converge

#--> remove the interactions involving age
full=glmer(normalNAd ~ (1|participant)+ (1|verb) + ageM + token.freq + subclass.PND  + subclass.PND:token.freq, data=data3, family=binomial)
#converged!

summary(full)
# Fixed effects:
                        # Estimate Std. Error z value Pr(>|z|)    
# (Intercept)              3.09184    0.24068  12.846  < 2e-16 ***
# ageM                     0.08210    0.02753   2.982  0.00286 ** 
# token.freq               0.37986    0.06429   5.909 3.45e-09 ***
# subclass.PND             0.16744    0.06530   2.564  0.01034 *  
# token.freq:subclass.PND  0.02068    0.03098   0.668  0.50428    

### Removing the interaction between PND and token

MainEffectsOnly = update(full, . ~ . - subclass.PND:token.freq)
summary(MainEffectsOnly)
anova(full, MainEffectsOnly)
#not significant: p=0.5044, chisq=0.4456

## obtaining p value for token frequency
Token = update(MainEffectsOnly, . ~ . - token.freq)
anova(MainEffectsOnly, Token)
summary(Token)
#significant: p=3.953e-10, chisq=39.136

##p value for PND
Phon = update(MainEffectsOnly, . ~ . - subclass.PND)
anova(MainEffectsOnly, Phon)
summary(Phon)
#significant: p=0.01619, chisq=5.7819

##p value for age
AgeM = update(MainEffectsOnly, . ~ . - ageM)
anova(MainEffectsOnly, AgeM)
summary(AgeM)
#significant: p=0.003159, chisq=8.7132

