#clear workspace
rm(list = ls())

#+ setup, include=FALSE
library(lme4)

setwd("~/")

#+ include=FALSE
data1 <- read.csv("Polish_dataset-final.csv",header=T)

#stats

data1=subset(data1, !is.na(normalNAd))

#centering age to 48 months
center_mean <- function(x) {
    x_mean=48
    x - x_mean
}

# apply it
data1$age=center_mean(data1$ageM)
head(data1)
data1$normalNAd

#centering the PND and token freq data to the mean (trying to prevent convergence failures)
data1$group.PND=log(data1$group.PND)
data1$token.freq3=log(data1$token.freq3+1)

mean.group.PND=mean(data1$group.PND)
mean.token.freq3=mean(data1$token.freq3)


#for token.freq
# mean subtraction
center_mean <- function(x) {
    x_mean=mean.token.freq3
    x - x_mean
}

# apply it
data1$token.freq3=center_mean(data1$token.freq3)
head(data1)

#for PND
# mean subtraction
center_mean <- function(x) {
    x_mean=mean.group.PND
    x - x_mean
}

# apply it
data1$group.PND=center_mean(data1$group.PND)
head(data1)


####analysis#### 

data1=subset(data1, !is.na(normalNAd))

##simple random structure model
full=glmer(normalNAd~ (1|participant)+(1|verb)+group.PND+token.freq3+ageM+group.PND:token.freq3+group.PND:ageM+token.freq3:ageM, data=data1, family=binomial)
summary(full)
#didn't converge 

##remove the interaction with age 
full=glmer(normalNAd~ (1|participant)+(1|verb)+group.PND+token.freq3+ageM+group.PND:token.freq3, data=data1, family=binomial)
summary(full)
#converged!

### Removing an interaction between PND and token 
MainEffectsOnly = update(full, . ~ . - group.PND:token.freq3)
summary(MainEffectsOnly)
anova(full, MainEffectsOnly)
#p=0.4841

#obtaining p value for token frequency
Token = update(MainEffectsOnly, . ~ . - token.freq3)
anova(MainEffectsOnly, Token)
#p=3.677e-08 ***

#p value for PND
Phon = update(MainEffectsOnly, . ~ . - group.PND)
anova(MainEffectsOnly, Phon)
#p=0.002101

#p value for age
Age = update(MainEffectsOnly, . ~ . - ageM)
anova(MainEffectsOnly, Age)
#p=0.1208

